@@ -1,7 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
-    Copyright (C) 2007-2009 Piotr Eljasiak
+    Copyright (C) 2007-2011 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -167,7 +167,7 @@ inline void GnomeCmdFileSelector::update_selected_files_label()
         switch (f->info->type)
         {
             case GNOME_VFS_FILE_TYPE_DIRECTORY:
-                if (strcmp(f->info->name, "..") != 0)
+                if (!f->is_dotdot)
                 {
                     num_dirs++;
                     if (gnome_cmd_file_has_tree_size (f))
@@ -397,7 +397,7 @@ drag_data_received (GtkWidget          *widget,
         /* The drop was over a directory in the list, which means that the
          * xfer should be done to that directory instead of the current one in the list
          */
-        if (strcmp (f->info->name, "..") == 0)
+        if (f->is_dotdot)
             to = gnome_cmd_dir_get_parent (cwd);
         else
             to = gnome_cmd_dir_get_child (cwd, f->info->name);
@@ -422,11 +422,6 @@ drag_data_received (GtkWidget          *widget,
 }
 
 
-static void drag_begin (GtkWidget *widget, GdkDragContext *context, GnomeCmdFileSelector *fs)
-{
-}
-
-
 static void drag_end (GtkWidget *widget, GdkDragContext *context, GnomeCmdFileSelector *fs)
 {
     restore_drag_indicator (fs);
@@ -565,7 +560,6 @@ inline void init_dnd (GnomeCmdFileSelector *fs)
     g_return_if_fail (GNOME_CMD_IS_FILE_SELECTOR (fs));
 
     // Set up drag source
-    gtk_signal_connect (GTK_OBJECT (fs->file_list()), "drag-begin", GTK_SIGNAL_FUNC (drag_begin), fs);
     gtk_signal_connect (GTK_OBJECT (fs->file_list()), "drag-end", GTK_SIGNAL_FUNC (drag_end), fs);
     gtk_signal_connect (GTK_OBJECT (fs->file_list()), "drag-leave", GTK_SIGNAL_FUNC (drag_leave), fs);
     gtk_signal_connect (GTK_OBJECT (fs->file_list()), "drag-data-delete", GTK_SIGNAL_FUNC (drag_data_delete), fs);
@@ -706,7 +700,7 @@ static void do_file_specific_action (GnomeCmdFileSelector *fs, GnomeCmdFile *f)
     {
         fs->file_list()->invalidate_tree_size();
 
-        if (strcmp (f->info->name, "..") == 0)
+        if (f->is_dotdot)
             fs->goto_directory("..");
         else
             fs->set_directory(GNOME_CMD_DIR (f));
@@ -1698,7 +1692,7 @@ static gboolean on_new_textfile_ok (GnomeCmdStringDialog *string_dialog, const g
     g_free (escaped_filepath);
 
     if (cmd)
-        run_command (cmd, FALSE);
+        run_command (cmd);
 
     return TRUE;
 }
@@ -1749,6 +1743,11 @@ void gnome_cmd_file_selector_show_new_textfile_dialog (GnomeCmdFileSelector *fs)
                                           (GnomeCmdStringDialogCallback) on_new_textfile_ok, fs);
     g_return_if_fail (GNOME_CMD_IS_DIALOG (dialog));
 
+    GnomeCmdFile *f = fs->file_list()->get_selected_file();
+
+    if (f)
+        gnome_cmd_string_dialog_set_value (GNOME_CMD_STRING_DIALOG (dialog), 0, f->info->name);
+
     gtk_widget_ref (dialog);
     gtk_widget_show (dialog);
 }
@@ -1795,15 +1794,18 @@ gboolean GnomeCmdFileSelector::key_pressed(GdkEventKey *event)
         switch (event->keyval)
         {
             case GDK_Down:
+            case GDK_KP_Down:
                 gnome_cmd_dir_indicator_show_history (GNOME_CMD_DIR_INDICATOR (dir_indicator));
                 return TRUE;
 
             case GDK_Left:
+            case GDK_KP_Left:
                 back();
                 stop_kp (GTK_OBJECT (file_list()));
                 return TRUE;
 
             case GDK_Right:
+            case GDK_KP_Right:
                 forward();
                 stop_kp (GTK_OBJECT (file_list()));
                 return TRUE;
@@ -1834,10 +1836,12 @@ gboolean GnomeCmdFileSelector::key_pressed(GdkEventKey *event)
                 return TRUE;
 
             case GDK_Page_Up:
+            case GDK_KP_Page_Up:
                 goto_directory("..");
                 return TRUE;
 
             case GDK_Page_Down:
+            case GDK_KP_Page_Down:
                 f = file_list()->get_selected_file();
                 if (f && f->info->type == GNOME_VFS_FILE_TYPE_DIRECTORY)
                     do_file_specific_action (this, f);
